<?php

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

//
// sépare à la lisp le premier mot et les autres
//
// $f (string) : liste à séparer
// $cdr (string ou array) : valeur par défaut pour le 2eme élt renvoyé
// $string_wanted (bool) : type du 2eme élément renvoyé
//
// retour (array) :
// retour[0] (string) : 1er élément de la liste
// retour[1] (string ou array selon $string_wanted) : reste de la liste
//
/**
 * @param string $l             liste de termes
 * @param string $cdr           suite par défaut
 * @param bool $string_wanted   cdr renvoyé comme chaine ou comme tableau
 * @return array                renvoie un tableau [ car, cdr ]
 *      où car est le premier élément de la liste
 *      et cdr est le reste de la liste, ou le cdr reçu en argument s'il n'y a pas de reste
 *
 */
function split_first_arg($l, $cdr = '', $string_wanted = true) {
	$l = preg_replace('/\s+/', ' ', trim($l), -1, $n);
	$lparts = explode(' ', $l);
	if ($lparts != array_filter($lparts)) {
		spip_log("split_first_arg($l, $cdr, $string_wanted); mauvais format du 1er argument".print_r($lparts, 1), 'cachelab_ASSERT');
		exit;
	}
	$car = array_shift($lparts);
	if (!$car) {
		spip_log("split_first_arg($l,$cdr,$string_wanted) : pb avec le 1er argument, reste lparts=".print_r($lparts, 1), 'cachelab_ASSERT');
		exit;
	}

	if ($lparts) {
		if ($string_wanted) {
			$cdr = implode(' ', $lparts);
		} else {
			$cdr = $lparts;
		}
	}

	return array ($car, $cdr);
}

/**
 * @param string $chemin
 * @param string $sep
 * @return string   remplace les / par des _
 */
function slug_chemin($chemin, $sep = '_') {
	return str_replace('/', $sep, $chemin);
}


/**
 * @param string $cond              signal d'invalidation
 *       typiquement de la forme : "id='document/1234'" ou "id='article/567'"
 *       ... mais parfois aussi de la forme "id='id_document/1234'" 
 * @param string $objet_attendu     id_objet attendu : 'id_document' ou 'id_article'
 * @param string &$objet            objet effectivement trouvé dans $cond : 'document' ou 'article' (ou 'id_document' actuellement si c'est ce qui est reçu hmmm...)
 * @return int|null
 *
 * Fenvoie l'id_objet ciblé par le signal, ou null en cas d'erreur
 * 
 * Fonction utilitaire pour les fonctions cachelab_suivre_invalideur_xxx user-squelette-définies
 * Exemple :
 * function cachelab_suivre_invalideur_document($cond, $modif) {
 *	   include_spip('inc/cachelab');
 *     $id_doc = decoder_invalideur($cond, 'document');
 *     cachelab_cibler('del', array ('chemin'=>'documents', 'cle_objet'=>'id_document', 'id_objet'=>$id_doc));
 *     return false;
 * }
 */
function decoder_invalideur($cond, $objet_attendu = '', &$objet='') {
	if (!preg_match(',["\']([a-z_]+)[/"\'](.*)[/"\'],', $cond, $r)) {
		spip_log("Signal non conforme pour decode_signal_invalideur ($cond, $objet_attendu)", 'ERREUR_cachelab', 1);
		return null;
	}
	list (, $objet, $id_objet) = $r;        	// [0] est le match total
	// On vérifie 'objet' et 'id_objet' car il arrive que le signal soit mal formé
	if ($objet_attendu and ($objet!=$objet_attendu) and ($objet!="id_$objet_attendu")) {
		spip_log(
			"decoder_invalideur($cond,) ne reçoit pas un '$objet_attendu' mais un '$objet' (avec id_objet='$id_objet'). Signal non conforme ?",
			'ERREUR_cachelab'
		);
		return null;
	}
	if (!$id_objet) {
		spip_log(
			"decoder_invalideur($cond, $objet_attendu) ne reçoit pas l'id pour '$objet'",
			'ERREUR_cachelab'
		);
		return null;
	}
	return $id_objet;
}
